<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name></name>
    <message>
        <source>Delete</source>
        <translation type="obsolete">Διαγραφή</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="obsolete">Πλήρης Οθόνη</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="obsolete">Προβολή εικονών</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="obsolete">Εξαγωγή</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="obsolete">Αντιγραφή</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="obsolete">Περιστροφή δεξιόστροφα</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="obsolete">Περιστροφή αριστερόστροφα</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="obsolete">Ορισμός ως ταπετσαρία</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="obsolete">Προβολή στον διαχειριστή αρχείων</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="obsolete">Πληροφορίες φωτογραφίας</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="obsolete">Επαναφορά</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>Χώρις όνομα</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Απόρριψη</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Δημιουργία</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>Νέο Άλμπουμ</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Απόρριψη</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>Είστε σίγουροι ότι θέλετε να διαγράψετε αυτό το άλμπουμ;</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>Κάδος Απορριμμάτων</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Αγαπημένα</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Εισαγωγή</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>Κάδος Απορριμμάτων</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Αγαπημένα</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>Ή σύρτε φωτογραφίες εδώ</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>Εισαγωγή όλων</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>Εισαγωγή σε:</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Εισαγωγή</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>Δίσκος Συστήματος</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Γκαλερί</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Ο δίσκος είναι απασχολημένος, αδυναμία εξαγωγής</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ΟΚ</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Νέο άλμπουμ</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Απόρριψη</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Αγνόηση</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image classification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>Άλμπουμ</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Απόρριψη</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Αντικατάσταση</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Εξαγωγή</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Εικόνες</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Έγγραφα</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Λήψεις</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Επιφάνει Εργασίας</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Βίντεο</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Μουσική</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Όνομα:</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Αποθήκευση σε:</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Τύπος αρχείου:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Ποιότητα</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Αποθήκευση</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>Επιλογή άλλων διευθύνσεων</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ΟΚ</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>Το όνομα αρχείου δεν μπορεί να είναι κενό</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>ήδη υπάρχει. Θέλετε να το αντικαταστήσετε;</translation>
    </message>
</context>
<context>
    <name>DBManager</name>
    <message>
        <source>Screen Capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(copy)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>%1 Δίσκος</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>Κενός %1 Δίσκος</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>%1 Κρυπτογραφημένος</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Τόμος</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>Αποθήκευση</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>Εξαγωγή Φωτογραφιών</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Απόρριψη</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>Διαγραφή...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>Επαναφορά...</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Απόρριψη</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete this file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot restore it any longer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete %1 files?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot restore them any longer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this file locally?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can restore it in the trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 files locally?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can restore them in the trash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Βασικές πληροφορίες</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Λεπτομέριες</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>Εισαγωγή</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>Προβολή εικονών</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Μετονομασία</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Εξαγωγή</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Συσκευή</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Γκαλερί</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Άλμπουμ</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Νέο άλμπουμ</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>Φωτογραφίες</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Πλήρης Οθόνη</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Βοήθεια</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Προβολή στον διαχειριστή αρχείων</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Προβολή εικονών</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Αντιγραφή</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Ορισμός ως ταπετσαρία</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Περιστροφή δεξιόστροφα</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Περιστροφή αριστερόστροφα</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Προηγούμενο</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Επόμενο</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Προσθήκη στα αγαπημένα</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Αφαίρεση από τα αγαπημένα</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>Μετονομασία άλμπουμ</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>Το Άλμπουμ “%1” αφαιρέθηκε</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>Επιτυχώς προστέθηκε στο “%1”</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>Επιτυχία εισαγωγής</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>Αποτυχία εισαγωγής </translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Αποτυχία εξαγωγής</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>Επιτυχία εισαγωγής</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>Όλες οι Φωτογραφίες</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>Χρονοδιαγράμματα</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Άλμπουμ</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>Έξοδος πλήρης οθόνης/παρουσίασης</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Προβολή συντομεύσεων</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Προβολή</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Επιλογή όλων</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Μεγεύθυνση</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Σμίκρυνση</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Νέο άλμπουμ</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Σελίδα πάνω</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Σελίδα κάτω</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Εισαγωγή...</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Διαγραφή</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import interrupted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot add this path, please try another one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The path already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to restore %1 files: file name too long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>Φλας</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Τύπος</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Μέγεθος αρχείου</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Διαστάσεις</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Ημερομηνία λήψης</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Ημερομηνία τροποποίησης</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Ρυθμίσεις έκθεσης</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Πρόγραμμα έκθεσης</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Χρόνος έκθεσης</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Διάφραγμα</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Εστιακή απόσταση</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Μέγιστο διάφραγμα</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Λειτουργία μέτρησης</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Ισορροπία λευκού</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Αντιστάθμιση Φλας</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Μοντέλο κάμερας</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Μοντέλο φακών</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Χρωματικός χώρος</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Ετικέτα</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>Δίσκος Συστήματος</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>Επιλογή</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Απόριψη επιλογής</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1/%2/%3</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>Εισάχθηκαν σε</translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation> %1-%2-%3 %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation>Εισάχθηκαν σε</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Απόρριψη</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Επαναφορά</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>Φωτογραφίες</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Βίντεο</translation>
    </message>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Προσθήκη στα αγαπημένα</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Περιστροφή αριστερόστροφα</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Περιστροφή δεξιόστροφα</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Εισαγωγή...</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1/%2 items classifyed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scenery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Humans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scene</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plants</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>Δεν βρέθηκαν αποτελέσματα</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>Παρουσίαση εικονών</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>Αποτελέσματα αναζήτησης</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>Προβολή</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Πλήρης Οθόνη</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Εξαγωγή</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Αγαπημένο</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Αφαίρεση από τα αγαπημένα</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Περιστροφή δεξιόστροφα</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Περιστροφή αριστερόστροφα</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Προβολή στον διαχειριστή αρχείων</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Ορισμός ως ταπετσαρία</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Προβολή εικονών</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Αντιγραφή</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>Πληροφορίες φωτογραφίας</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Προσθήκη σε άλμπουμ</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Αφαίρεση από άλμπουμ</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Επαναφορά</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Νέο άλμπουμ</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Εκτύπωση</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished">Ημέρες</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation type="unfinished">Βασικές πληροφορίες</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation type="unfinished">Ημερομηνία τροποποίησης</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Τύπος</translation>
    </message>
    <message>
        <source>File size</source>
        <translation type="unfinished">Μέγεθος αρχείου</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished">Ημερομηνία λήψης</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
